==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/IOChaosActionFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;

 /**
  * Generated
  */
public interface IOChaosActionFluent<A extends IOChaosActionFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAtime instead.
   * @return The buildable object.
   */
  @Deprecated
  public Timespec getAtime();
  public Timespec buildAtime();
  public A withAtime(Timespec atime);
  public Boolean hasAtime();
  public A withNewAtime(Long nsec,Long sec);
  public IOChaosActionFluent.AtimeNested<A> withNewAtime();
  public IOChaosActionFluent.AtimeNested<A> withNewAtimeLike(Timespec item);
  public IOChaosActionFluent.AtimeNested<A> editAtime();
  public IOChaosActionFluent.AtimeNested<A> editOrNewAtime();
  public IOChaosActionFluent.AtimeNested<A> editOrNewAtimeLike(Timespec item);
  public Long getBlocks();
  public A withBlocks(Long blocks);
  public Boolean hasBlocks();
  
  /**
   * This method has been deprecated, please use method buildCtime instead.
   * @return The buildable object.
   */
  @Deprecated
  public Timespec getCtime();
  public Timespec buildCtime();
  public A withCtime(Timespec ctime);
  public Boolean hasCtime();
  public A withNewCtime(Long nsec,Long sec);
  public IOChaosActionFluent.CtimeNested<A> withNewCtime();
  public IOChaosActionFluent.CtimeNested<A> withNewCtimeLike(Timespec item);
  public IOChaosActionFluent.CtimeNested<A> editCtime();
  public IOChaosActionFluent.CtimeNested<A> editOrNewCtime();
  public IOChaosActionFluent.CtimeNested<A> editOrNewCtimeLike(Timespec item);
  public A addToFaults(Integer index,IoFault item);
  public A setToFaults(Integer index,IoFault item);
  public A addToFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
  public A addAllToFaults(Collection<IoFault> items);
  public A removeFromFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
  public A removeAllFromFaults(Collection<IoFault> items);
  public A removeMatchingFromFaults(Predicate<IoFaultBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFaults instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IoFault> getFaults();
  public List<IoFault> buildFaults();
  public IoFault buildFault(Integer index);
  public IoFault buildFirstFault();
  public IoFault buildLastFault();
  public IoFault buildMatchingFault(Predicate<IoFaultBuilder> predicate);
  public Boolean hasMatchingFault(Predicate<IoFaultBuilder> predicate);
  public A withFaults(List<IoFault> faults);
  public A withFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... faults);
  public Boolean hasFaults();
  public A addNewFault(Integer errno,Integer weight);
  public IOChaosActionFluent.FaultsNested<A> addNewFault();
  public IOChaosActionFluent.FaultsNested<A> addNewFaultLike(IoFault item);
  public IOChaosActionFluent.FaultsNested<A> setNewFaultLike(Integer index,IoFault item);
  public IOChaosActionFluent.FaultsNested<A> editFault(Integer index);
  public IOChaosActionFluent.FaultsNested<A> editFirstFault();
  public IOChaosActionFluent.FaultsNested<A> editLastFault();
  public IOChaosActionFluent.FaultsNested<A> editMatchingFault(Predicate<IoFaultBuilder> predicate);
  public Long getGid();
  public A withGid(Long gid);
  public Boolean hasGid();
  public Long getIno();
  public A withIno(Long ino);
  public Boolean hasIno();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getLatency();
  public A withLatency(String latency);
  public Boolean hasLatency();
  public A addToMethods(Integer index,String item);
  public A setToMethods(Integer index,String item);
  public A addToMethods(java.lang.String... items);
  public A addAllToMethods(Collection<String> items);
  public A removeFromMethods(java.lang.String... items);
  public A removeAllFromMethods(Collection<String> items);
  public List<String> getMethods();
  public String getMethod(Integer index);
  public String getFirstMethod();
  public String getLastMethod();
  public String getMatchingMethod(Predicate<String> predicate);
  public Boolean hasMatchingMethod(Predicate<String> predicate);
  public A withMethods(List<String> methods);
  public A withMethods(java.lang.String... methods);
  public Boolean hasMethods();
  
  /**
   * This method has been deprecated, please use method buildMistake instead.
   * @return The buildable object.
   */
  @Deprecated
  public MistakeSpec getMistake();
  public MistakeSpec buildMistake();
  public A withMistake(MistakeSpec mistake);
  public Boolean hasMistake();
  public A withNewMistake(String filling,Long maxLength,Long maxOccurrences);
  public IOChaosActionFluent.MistakeNested<A> withNewMistake();
  public IOChaosActionFluent.MistakeNested<A> withNewMistakeLike(MistakeSpec item);
  public IOChaosActionFluent.MistakeNested<A> editMistake();
  public IOChaosActionFluent.MistakeNested<A> editOrNewMistake();
  public IOChaosActionFluent.MistakeNested<A> editOrNewMistakeLike(MistakeSpec item);
  
  /**
   * This method has been deprecated, please use method buildMtime instead.
   * @return The buildable object.
   */
  @Deprecated
  public Timespec getMtime();
  public Timespec buildMtime();
  public A withMtime(Timespec mtime);
  public Boolean hasMtime();
  public A withNewMtime(Long nsec,Long sec);
  public IOChaosActionFluent.MtimeNested<A> withNewMtime();
  public IOChaosActionFluent.MtimeNested<A> withNewMtimeLike(Timespec item);
  public IOChaosActionFluent.MtimeNested<A> editMtime();
  public IOChaosActionFluent.MtimeNested<A> editOrNewMtime();
  public IOChaosActionFluent.MtimeNested<A> editOrNewMtimeLike(Timespec item);
  public Long getNlink();
  public A withNlink(Long nlink);
  public Boolean hasNlink();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public Integer getPercent();
  public A withPercent(Integer percent);
  public Boolean hasPercent();
  public Integer getPerm();
  public A withPerm(Integer perm);
  public Boolean hasPerm();
  public Long getRdev();
  public A withRdev(Long rdev);
  public Boolean hasRdev();
  public Long getSize();
  public A withSize(Long size);
  public Boolean hasSize();
  public String getSource();
  public A withSource(String source);
  public Boolean hasSource();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public Long getUid();
  public A withUid(Long uid);
  public Boolean hasUid();
  public interface AtimeNested<N> extends Nested<N>,TimespecFluent<IOChaosActionFluent.AtimeNested<N>>{
    public N and();
    public N endAtime();
    
  }
  public interface CtimeNested<N> extends Nested<N>,TimespecFluent<IOChaosActionFluent.CtimeNested<N>>{
    public N and();
    public N endCtime();
    
  }
  public interface FaultsNested<N> extends Nested<N>,IoFaultFluent<IOChaosActionFluent.FaultsNested<N>>{
    public N and();
    public N endFault();
    
  }
  public interface MistakeNested<N> extends Nested<N>,MistakeSpecFluent<IOChaosActionFluent.MistakeNested<N>>{
    public N and();
    public N endMistake();
    
  }
  public interface MtimeNested<N> extends Nested<N>,TimespecFluent<IOChaosActionFluent.MtimeNested<N>>{
    public N and();
    public N endMtime();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/IOChaosActionFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;

 /**
  * Generated
  */
public interface IOChaosActionFluent<A extends IOChaosActionFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAtime instead.
   * @return The buildable object.
   */
  @Deprecated
  public Timespec getAtime();
  public Timespec buildAtime();
  public A withAtime(Timespec atime);
  public Boolean hasAtime();
  public A withNewAtime(Long nsec,Long sec);
  public IOChaosActionFluent.AtimeNested<A> withNewAtime();
  public IOChaosActionFluent.AtimeNested<A> withNewAtimeLike(Timespec item);
  public IOChaosActionFluent.AtimeNested<A> editAtime();
  public IOChaosActionFluent.AtimeNested<A> editOrNewAtime();
  public IOChaosActionFluent.AtimeNested<A> editOrNewAtimeLike(Timespec item);
  public Long getBlocks();
  public A withBlocks(Long blocks);
  public Boolean hasBlocks();
  
  /**
   * This method has been deprecated, please use method buildCtime instead.
   * @return The buildable object.
   */
  @Deprecated
  public Timespec getCtime();
  public Timespec buildCtime();
  public A withCtime(Timespec ctime);
  public Boolean hasCtime();
  public A withNewCtime(Long nsec,Long sec);
  public IOChaosActionFluent.CtimeNested<A> withNewCtime();
  public IOChaosActionFluent.CtimeNested<A> withNewCtimeLike(Timespec item);
  public IOChaosActionFluent.CtimeNested<A> editCtime();
  public IOChaosActionFluent.CtimeNested<A> editOrNewCtime();
  public IOChaosActionFluent.CtimeNested<A> editOrNewCtimeLike(Timespec item);
  public A addToFaults(int index,IoFault item);
  public A setToFaults(int index,IoFault item);
  public A addToFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
  public A addAllToFaults(Collection<IoFault> items);
  public A removeFromFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... items);
  public A removeAllFromFaults(Collection<IoFault> items);
  public A removeMatchingFromFaults(Predicate<IoFaultBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFaults instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IoFault> getFaults();
  public List<IoFault> buildFaults();
  public IoFault buildFault(int index);
  public IoFault buildFirstFault();
  public IoFault buildLastFault();
  public IoFault buildMatchingFault(Predicate<IoFaultBuilder> predicate);
  public Boolean hasMatchingFault(Predicate<IoFaultBuilder> predicate);
  public A withFaults(List<IoFault> faults);
  public A withFaults(io.fabric8.chaosmesh.v1alpha1.IoFault... faults);
  public Boolean hasFaults();
  public A addNewFault(Integer errno,Integer weight);
  public IOChaosActionFluent.FaultsNested<A> addNewFault();
  public IOChaosActionFluent.FaultsNested<A> addNewFaultLike(IoFault item);
  public IOChaosActionFluent.FaultsNested<A> setNewFaultLike(int index,IoFault item);
  public IOChaosActionFluent.FaultsNested<A> editFault(int index);
  public IOChaosActionFluent.FaultsNested<A> editFirstFault();
  public IOChaosActionFluent.FaultsNested<A> editLastFault();
  public IOChaosActionFluent.FaultsNested<A> editMatchingFault(Predicate<IoFaultBuilder> predicate);
  public Long getGid();
  public A withGid(Long gid);
  public Boolean hasGid();
  public Long getIno();
  public A withIno(Long ino);
  public Boolean hasIno();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public String getLatency();
  public A withLatency(String latency);
  public Boolean hasLatency();
  public A addToMethods(int index,String item);
  public A setToMethods(int index,String item);
  public A addToMethods(java.lang.String... items);
  public A addAllToMethods(Collection<String> items);
  public A removeFromMethods(java.lang.String... items);
  public A removeAllFromMethods(Collection<String> items);
  public List<String> getMethods();
  public String getMethod(int index);
  public String getFirstMethod();
  public String getLastMethod();
  public String getMatchingMethod(Predicate<String> predicate);
  public Boolean hasMatchingMethod(Predicate<String> predicate);
  public A withMethods(List<String> methods);
  public A withMethods(java.lang.String... methods);
  public Boolean hasMethods();
  
  /**
   * This method has been deprecated, please use method buildMistake instead.
   * @return The buildable object.
   */
  @Deprecated
  public MistakeSpec getMistake();
  public MistakeSpec buildMistake();
  public A withMistake(MistakeSpec mistake);
  public Boolean hasMistake();
  public A withNewMistake(String filling,Long maxLength,Long maxOccurrences);
  public IOChaosActionFluent.MistakeNested<A> withNewMistake();
  public IOChaosActionFluent.MistakeNested<A> withNewMistakeLike(MistakeSpec item);
  public IOChaosActionFluent.MistakeNested<A> editMistake();
  public IOChaosActionFluent.MistakeNested<A> editOrNewMistake();
  public IOChaosActionFluent.MistakeNested<A> editOrNewMistakeLike(MistakeSpec item);
  
  /**
   * This method has been deprecated, please use method buildMtime instead.
   * @return The buildable object.
   */
  @Deprecated
  public Timespec getMtime();
  public Timespec buildMtime();
  public A withMtime(Timespec mtime);
  public Boolean hasMtime();
  public A withNewMtime(Long nsec,Long sec);
  public IOChaosActionFluent.MtimeNested<A> withNewMtime();
  public IOChaosActionFluent.MtimeNested<A> withNewMtimeLike(Timespec item);
  public IOChaosActionFluent.MtimeNested<A> editMtime();
  public IOChaosActionFluent.MtimeNested<A> editOrNewMtime();
  public IOChaosActionFluent.MtimeNested<A> editOrNewMtimeLike(Timespec item);
  public Long getNlink();
  public A withNlink(Long nlink);
  public Boolean hasNlink();
  public String getPath();
  public A withPath(String path);
  public Boolean hasPath();
  public Integer getPercent();
  public A withPercent(Integer percent);
  public Boolean hasPercent();
  public Integer getPerm();
  public A withPerm(Integer perm);
  public Boolean hasPerm();
  public Long getRdev();
  public A withRdev(Long rdev);
  public Boolean hasRdev();
  public Long getSize();
  public A withSize(Long size);
  public Boolean hasSize();
  public String getSource();
  public A withSource(String source);
  public Boolean hasSource();
  public String getType();
  public A withType(String type);
  public Boolean hasType();
  public Long getUid();
  public A withUid(Long uid);
  public Boolean hasUid();
  public interface AtimeNested<N> extends Nested<N>,TimespecFluent<IOChaosActionFluent.AtimeNested<N>>{
    public N and();
    public N endAtime();
    
  }
  public interface CtimeNested<N> extends Nested<N>,TimespecFluent<IOChaosActionFluent.CtimeNested<N>>{
    public N and();
    public N endCtime();
    
  }
  public interface FaultsNested<N> extends Nested<N>,IoFaultFluent<IOChaosActionFluent.FaultsNested<N>>{
    public N and();
    public N endFault();
    
  }
  public interface MistakeNested<N> extends Nested<N>,MistakeSpecFluent<IOChaosActionFluent.MistakeNested<N>>{
    public N and();
    public N endMistake();
    
  }
  public interface MtimeNested<N> extends Nested<N>,TimespecFluent<IOChaosActionFluent.MtimeNested<N>>{
    public N and();
    public N endMtime();
    
  }
  
}
